OC.L10N.register(
    "files",
    {
    "Added to favorites" : "즐겨찾기에 추가됨",
    "Removed from favorites" : "즐겨찾기에서 삭제됨",
    "You added {file} to your favorites" : "내가 {file}을(를) 즐겨찾기에 추가함",
    "You removed {file} from your favorites" : "내가 {file}을(를) 즐겨찾기에서 삭제함",
    "Favorites" : "즐겨찾기",
    "File changes" : "파일 변경",
    "Created by {user}" : "{user} 님이 만듦",
    "Changed by {user}" : "{user} 님이 변경함",
    "Deleted by {user}" : "{user} 님이 삭제함",
    "Restored by {user}" : "{user} 님이 복원함",
    "Renamed by {user}" : "{user} 님이 이름을 변경함",
    "Moved by {user}" : "{user} 님이 이동함",
    "\"remote account\"" : "\"원격 계정\"",
    "You created {file}" : "{file}을(를) 만듦",
    "You created an encrypted file in {file}" : "{file}에 암호화된 파일을 생성했습니다.",
    "{user} created {file}" : "{user} 님이 {file}을(를) 만듦",
    "{user} created an encrypted file in {file}" : "{user}님이 {file}에 암호화된 파일을 생성",
    "{file} was created in a public folder" : "공유 폴더에 {file}이(가) 생성됨",
    "You changed {file}" : "{file}을(를) 변경함",
    "You changed an encrypted file in {file}" : "{file}에 암호화된 파일을 변경했습니다.",
    "{user} changed {file}" : "{user} 님이 {file}을(를) 변경함",
    "{user} changed an encrypted file in {file}" : "{user}님이 {file}에 암호화된 파일을 변경",
    "You deleted {file}" : "{file}을(를) 삭제함",
    "You deleted an encrypted file in {file}" : "{file}에 암호화된 파일을 제거했습니다.",
    "{user} deleted {file}" : "{user} 님이 {file}을(를) 삭제함",
    "{user} deleted an encrypted file in {file}" : "{user}님이 {file}에 암호화된 파일을 제거",
    "You restored {file}" : "내가 {file}을(를) 복원함",
    "{user} restored {file}" : "{user} 님이 {file}을(를) 복원함",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (숨겨짐)을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (숨겨짐)을(를) {newfile}(으)로 이름을 바꿈",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "You renamed {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user}님이 {oldfile} (숨겨짐)을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user}님이 {oldfile} (숨겨짐)을(를) {newfile}(으)로 이름을 바꿈",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}님이 {oldfile}을(를) {newfile} (숨겨짐)(으)로 이름을 바꿈",
    "{user} renamed {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "You moved {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이동함",
    "{user} moved {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이동함",
    "A file has been added to or removed from your <strong>favorites</strong>" : "파일이 <strong>즐겨찾기</strong>에서 추가 또는 삭제됨",
    "Files" : "파일",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "즐겨찾기된 파일이나 폴더가 <strong>변경됨</strong>",
    "Failed to authorize" : "인증 실패하였습니다",
    "Invalid folder path" : "잘못된 폴더 경로",
    "Folder not found" : "폴더를 찾을 수 없음",
    "The file cannot be found" : "파일을 찾을 수 없습니다",
    "The destination path does not exist: %1$s" : "목표한 경로가 존재하지 않습니다: %1$s",
    "You do not have permission to create a file at the specified location" : "지정한 위치에 파일을 생성할 권한이 없습니다.",
    "The file could not be converted." : "파일이 변환될 수 없습니다.",
    "Could not get relative path to converted file" : "변환될 파일의 상대 경로를 알 수 없습니다",
    "Favorite files" : "즐겨찾는 파일",
    "No favorites" : "즐겨찾는 항목 없음",
    "More favorites" : "즐겨찾기 더 불러오기",
    "Accept" : "수락",
    "Reject" : "거절",
    "Incoming ownership transfer from {user}" : "{user}의 소유권 이전 요청",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path}의 소유권을 받으시겠습니까?\n\n참고: 이전 과정은 동의한 시점으로부터 최대 1시간 소요됩니다.",
    "Ownership transfer denied" : "소유권 이전 거절",
    "Your ownership transfer of {path} was denied by {user}." : "{user}을(를) 향한 {path}의 소유권 이전이 거절되었습니다.",
    "Ownership transfer failed" : "소유권 이전 실패",
    "Your ownership transfer of {path} to {user} failed." : "{user}을(를) 향한 {path}의 소유권 이전에 실패했습니다.",
    "The ownership transfer of {path} from {user} failed." : "{user}(으)로부터 {path}의 소유권을 받는 것에 실패했습니다.",
    "Ownership transfer done" : "소유권 이전 완료",
    "Your ownership transfer of {path} to {user} has completed." : "{user}을(를) 향한 {path}의 소유권 이전을 완료했습니다.",
    "The ownership transfer of {path} from {user} has completed." : "{user}(으)로부터 {path}의 소유권을 받았습니다.",
    "in %s" : "%s",
    "Transferred from %1$s on %2$s" : "%2$s의 %1$s에서 전송됨",
    "File Management" : "파일 관리",
    "Home" : "홈",
    "Target folder does not exist any more" : "대상 폴더가 더 이상 존재하지 않습니다",
    "Reload current directory" : "이 경로를 새로고침",
    "Go to the \"{dir}\" directory" : "\"{dir}\" 경로로 이동",
    "Current directory path" : "현재 디렉토리 경로",
    "Your have used your space quota and cannot upload files anymore" : "저장소 할당량을 모두 사용하여 더 이상 파일을 업로드할 수 없습니다",
    "You do not have permission to upload or create files here." : "여기에 업로드하거나 파일을 생성할 권한이 없습니다.",
    "Drag and drop files here to upload" : "이곳에 파일을 드래그 앤 드롭해 업로드",
    "Favorite" : "즐겨찾기",
    "Back" : "뒤로",
    "Toggle selection for file \"{displayName}\"" : "파일 \"{displayName}\" 선택/선택해제",
    "Toggle selection for folder \"{displayName}\"" : "폴더 \"{displayName}\" 선택/선택해제",
    "File is loading" : "파일 불러오는 중",
    "Folder is loading" : "폴더 불러오는 중",
    "Filename" : "파일 이름",
    "Folder name" : "폴더 이름",
    "This node is unavailable" : "이 노드를 사용할 수 없습니다",
    "Another entry with the same name already exists." : "같은 이름의 항목이 이미 있습니다.",
    "Invalid filename." : "잘못된 파일 이름",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" 에서 \"{newName}\"(으)로 이름 변경함",
    "Rename file" : "파일 이름 바꾸기",
    "Folder" : "폴더",
    "Pending" : "대기 중",
    "Unknown date" : "알 수 없는 날짜",
    "Clear filter" : "필터 지우기",
    "Modified" : "수정됨",
    "Search everywhere" : "모든 곳에서 찾기",
    "Type" : "종류",
    "Active filters" : "활성 필터",
    "Remove filter" : "필터 삭제",
    "Appearance" : "외형",
    "Show hidden files" : "숨김 파일 보이기",
    "Show file type column" : "파일 형식 열 보이기",
    "Show file extensions" : "파일 확장자 보이기",
    "Crop image previews" : "이미지 미리보기 확대",
    "General" : "일반",
    "Sort favorites first" : "즐겨찾기를 처음에 나열",
    "Sort folders before files" : "폴더를 파일보다 먼저 정렬",
    "Default view" : "기본 보기",
    "All files" : "모든 파일",
    "Personal files" : "개인 파일",
    "Additional settings" : "고급 설정",
    "Actions" : "작업",
    "File actions" : "파일 동작",
    "Selection" : "선택",
    "Select all files" : "모든 파일 선택",
    "Deselect all" : "모두 선택 해제",
    "Select or deselect" : "선택 또는 선택 해제",
    "Select a range" : "범위 선택",
    "Navigation" : "탐색",
    "Go to parent folder" : "상위 폴더로 이동",
    "Go to file above" : "위 파일로 이동",
    "Go to file below" : "아래 파일로 이동",
    "Go left in grid" : "그리드에서 왼쪽으로 이동",
    "Go right in grid" : "그리드에서 오른쪽으로 이동",
    "View" : "보기",
    "Toggle grid view" : "그리드뷰 전환",
    "Open file sidebar" : "파일 사이드바 열기",
    "Show those shortcuts" : "다음 단축키 표시",
    "Warnings" : "경고",
    "Warn before changing a file extension" : "파일 확장자 변경 시 경고",
    "WebDAV URL" : "WebDAV URL",
    "How to access files using WebDAV" : "WebDAV를 사용해 파일에 접근하는 방법",
    "Total rows summary" : "총 행 요약",
    "Toggle selection for all files and folders" : "모든 파일 선택/선택해제",
    "Name" : "이름",
    "Size" : "크기",
    "(selected)" : "(선택됨)",
    "List of files and folders." : "파일과 폴더의 목록",
    "You have used your space quota and cannot upload files anymore." : "저장소 할당량을 모두 사용하여 더 이상 파일을 업로드할 수 없습니다.",
    "Column headers with buttons are sortable." : "버튼이 있는 열 머리글은 정렬할 수 있습니다.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "성능 상의 이유로 목록을 전부 표시하지 않았습니다. 목록을 탐색하면 파일들이 표시됩니다.",
    "File not found" : "파일을 찾을 수 없음",
    "Search everywhere …" : "모든 곳에서 검색 ...",
    "Search here …" : "여기서 검색 ...",
    "Search here" : "여기서 검색",
    "Owner" : "소유자",
    "{usedQuotaByte} used" : "{usedQuotaByte} 사용",
    "{used} of {quota} used" : "{quota} 중 {used} 사용함",
    "{relative}% used" : "{relative}% 사용",
    "Could not refresh storage stats" : "저장소 정보를 새로고칠 수 없음",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage information" : "저장소 정보",
    "Storage quota" : "저장소 할당량",
    "New folder" : "새 폴더",
    "Create new folder" : "새 폴더 생성",
    "This name is already in use." : "이 이름은 이미 사용 중입니다.",
    "Create" : "생성",
    "Refresh" : "새로 고침",
    "Fill template fields" : "양식 입력란 채우기",
    "Submit" : "제출",
    "Choose a file or folder to transfer" : "이전할 파일이나 폴더 고르기",
    "Transfer" : "이전",
    "Transfer {path} to {userid}" : "{path}을(를) {userid}에게 이전하기",
    "Invalid path selected" : "잘못된 경로가 선택됨",
    "Unknown error" : "알 수 없는 오류",
    "Ownership transfer request sent" : "소유권 이전 요청이 전송됨",
    "Cannot transfer ownership of a file or folder you do not own" : "내가 소유하지 않은 파일이나 폴더의 소유권을 이전할 수 없음",
    "Transfer ownership of a file or folder" : "파일이나 폴더의 소유권 이전",
    "Choose file or folder to transfer" : "이전할 파일이나 폴더 고르기",
    "Change" : "변경",
    "New owner" : "새 소유자",
    "Keep {old}" : "{old} 보관",
    "Keep without extension" : "연장하지 않고 보관",
    "Use {new}" : "{new}사용",
    "Remove extension" : "확장자 제거",
    "Change file extension" : "파일 확장자 변경",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "\"{old}\" 파일 확장자를 \"{new}\"(으)로 바꾸면 파일을 읽지 못할 수 있습니다.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "\"{old}\" 파일 확장자를 제거하면 파일을 읽지 못할 수 있습니다.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "\"{new}\" 파일 확장자를 추가하면 파일을 읽지 못할 수 있습니다.",
    "Do not show this dialog again." : "이 알림을 다시 보여주지 마세요.",
    "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
    "Choose {file}" : "{file} 선택",
    "Files settings" : "파일 설정",
    "Share" : "공유하기",
    "Shared by link" : "링크로 공유됨",
    "Shared" : "공유됨",
    "Switch to list view" : "목록 보기로 전환",
    "Switch to grid view" : "바둑판식 보기로 전환",
    "The file could not be found" : "파일을 찾을 수 없음",
    "Upload was cancelled by user" : "사용자에 의해 업로드가 취소됨",
    "Not enough free space" : "남은 공간이 부족함",
    "Operation is blocked by access control" : "접근 설정에 의해 동작이 차단됨",
    "Error during upload: {message}" : "업로드 오류: {message}",
    "Error during upload, status code {status}" : "업로드 중 오류 발생, 상태 코드 {status}",
    "Unknown error during upload" : "업로드 중 알 수 없는 오류 발생",
    "Loading current folder" : "현재 폴더를 불러오는 중",
    "Retry" : "다시 시도",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "Go back" : "뒤로 가기",
    "Views" : "보기",
    "Loading …" : "로딩 중 …",
    "Your files" : "내 파일",
    "Open in files" : "파일에서 열기",
    "File cannot be accessed" : "파일에 접근할 수 없음",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "파일을 찾을 수 없거나 볼 권한이 없습니다. 보낸 이에게 공유를 요청하세요.",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "모든 클라이언트와 동기화 될 수 있게 제한된 파일이름을 허용하세요. 기본적으로 POSIX (예를 들어 Linux 혹은 macOS) 에서 유효한 모든 파일이름은 허용됩니다.",
    "Files compatibility" : "파일 호환성",
    "Enforce Windows compatibility" : "윈도우 호환성 준수",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "예약어나 특수 문자 사용 등 Windows 시스템에서 유효하지 않은 파일 이름이 차단됩니다. 그러나 대소문자 구분의 호환성을 강제하지는 않습니다.",
    "Blank" : "여백",
    "Unable to create new file from template" : "템플릿으로 새 파일을 만들 수 없음",
    "Pick a template for {name}" : "{name}을(를) 위한 템플릿 선택",
    "Create a new file with the selected template" : "선택한 템플릿으로 새 파일 만들기",
    "Creating file" : "파일 만들기",
    "Save as {displayName}" : "{displayName}으로 저장하기",
    "Failed to convert files: {message}" : "파일 변환에 실패함:{message}",
    "All files failed to be converted" : "모든 파일이 변환에 실패했습니다.",
    "Failed to convert files" : "파일 변환에 실패했습니다",
    "Delete" : "삭제",
    "Leave this share" : "이 공유에서 떠나기",
    "Leave these shares" : "이 공유에서 떠나기",
    "Disconnect storage" : "저장소 연결 해제",
    "Disconnect storages" : "저장소 연결 끊기",
    "Delete permanently" : "영구히 삭제",
    "Delete and unshare" : "삭제 및 공유 해제",
    "Delete file" : "파일 삭제",
    "Delete files" : "파일 삭제",
    "Delete folder" : "폴더 삭제",
    "Delete folders" : "폴더 삭제",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}개 항목을 영구적으로 삭제하려 합니다."],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count}개 항목을 삭제하려 합니다."],
    "Confirm deletion" : "삭제 확인",
    "Cancel" : "취소",
    "Download" : "다운로드",
    "Add to favorites" : "즐겨찾기에 추가",
    "Remove from favorites" : "즐겨찾기에서 삭제",
    "Add or remove favorite" : "즐겨찾기 추가 또는 삭제",
    "Destination is not a folder" : "대상이 폴더가 아닙니다.",
    "This file/folder is already in that directory" : "이 파일/폴더가 이미 그 경로에 있습니다.",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "파일/폴더를 그 안이나 그 안의 폴더로 이동할 수 없습니다.",
    "(copy)" : "(복사)",
    "(copy %n)" : "(%n 복사)",
    "A file or folder with that name already exists in this folder" : "같은 이름을 사용하는 파일 또는 폴더가 이미 이 폴더에 있습니다.",
    "The files are locked" : "이 파일은 잠겼습니다",
    "The file does not exist anymore" : "파일이 더이상 존재하지 않습니다.",
    "Choose destination" : "목적지 선택",
    "Copy to {target}" : "{target}에 복사",
    "Copy" : "복사",
    "Move to {target}" : "{target}에 이동",
    "Move" : "이동",
    "Move or copy operation failed" : "이동 또는 복사 작업에 실패함",
    "Move or copy" : "이동이나 복사",
    "Open folder" : "폴더를 열 수 없음",
    "Open folder {displayName}" : "{displayName} 폴더 열기",
    "Open in Files" : "파일에서 열기",
    "Open locally" : "로컬에서 열기",
    "Failed to redirect to client" : "클라이언트로 리디렉션 하는데 실패함",
    "Open file locally" : "로컬에서 파일 열기",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "이제 이 파일이 당신의 기기에서 열려야 합니다. 그렇지 않다면, 데스크톱 앱이 설치되어 있는지 확인하세요.",
    "Retry and close" : "재시도 후 닫기",
    "Rename" : "이름 바꾸기",
    "Details" : "자세한 정보",
    "View in folder" : "폴더에서 보기",
    "Today" : "오늘",
    "Last 7 days" : "지난 7일",
    "Last 30 days" : "지난 30일",
    "This year ({year})" : "올해 ({year})",
    "Last year ({year})" : "작년 ({year})",
    "Documents" : "문서",
    "Spreadsheets" : "스프레드시트",
    "Presentations" : "프레젠테이션",
    "PDFs" : "PDF",
    "Folders" : "폴더",
    "Audio" : "오디오",
    "Images" : "이미지",
    "Videos" : "동영상",
    "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
    "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
    "Create templates folder" : "템플릿 폴더 만들기",
    "Templates" : "템플릿",
    "New template folder" : "새 템플릿 폴더",
    "In folder" : "폴더에서",
    "Search in folder: {folder}" : "폴더에서 검색: {folder}",
    "One of the dropped files could not be processed" : "드롭한 파일 중 하나를 처리할 수 없습니다",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "이 브라우저는 Filesystem API를 지원하지 않습니다. 디렉토리가 업로드 되지 않을 것입니다.",
    "No files to upload" : "업로드할 파일이 없음",
    "Unable to create the directory {directory}" : "디렉토리 {directory}을(를) 생성할 수 없음",
    "Some files could not be uploaded" : "일부 파일을 업로드할 수 없었습니다.",
    "Files uploaded successfully" : "파일을 성공적으로 업로드했습니다.",
    "No files to process" : "처리할 파일이 없음",
    "Some files could not be copied" : "일부 파일을 복사할 수 없음",
    "Some files could not be moved" : "일부 파일을 이동할 수 없음",
    "Files copied successfully" : "파일을 성공적으로 복사함",
    "Files moved successfully" : "파일을 성공적으로 이동함",
    "Conflicts resolution skipped" : "충돌 해결 건너뜀",
    "Upload cancelled" : "업로드가 취소됨",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\"(이)가 더이상 존재하지 않아 이름을 바꿀 수 없습니다.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" 이름이 \"{dir}\" 폴더에서 이미 사용 중입니다. 다른 이름을 고르세요.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\"의 이름을 바꿀 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "Storage is temporarily not available" : "저장소를 일시적으로 사용할 수 없음",
    "Unexpected error: {error}" : "예상치 못한 오류: {error}",
    "_%n file_::_%n files_" : ["파일 %n개"],
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "Filename must not be empty." : "파일 이름을 비울 수 없습니다.",
    "\"{char}\" is not allowed inside a filename." : "파일 이름에 \"{char}\"(을)를 사용할 수 없습니다.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\"(은)는 예약된 이름이므로 파일 이름에 사용할 수 없습니다.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\"(은)는 허용된 파일 형식이 아닙니다.",
    "Filenames must not end with \"{extension}\"." : "파일 이름은 \"{extension}\"(으)로 끝나야 합니다.",
    "List of favorite files and folders." : "즐겨찾는 파일과 폴더의 목록",
    "No favorites yet" : "즐겨찾는 항목 없음",
    "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
    "List of your files and folders." : "내 폴더와 파일의 목록",
    "Folder tree" : "폴더 트리",
    "List of your files and folders that are not shared." : "공유되지 않는 파일과 폴더의 목록",
    "No personal files found" : "개인 파일을 찾을 수 없음",
    "Files that are not shared will show up here." : "공유되지 않는 파일이 이곳에 나타납니다.",
    "Recent" : "최근",
    "List of recently modified files and folders." : "최근에 수정된 파일과 폴더의 목록",
    "No recently modified files" : "최근에 수정된 파일 없음",
    "Files and folders you recently modified will show up here." : "최근에 수정한 파일과 폴더가 이곳에 표시됩니다.",
    "Search" : "검색",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" 일부 요소로 실패",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
    "\"{displayName}\" action failed" : "\"{displayName}\" 작업을 실패함",
    "Submitting fields …" : "항목 제출 중 ...",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" 작업을 성공적으로 실행함",
    "Clipboard is not available" : "클립보드를 사용할 수 없습니다.",
    "WebDAV URL copied to clipboard" : "WebDAV URL이 클립보드에 복사됨",
    "Enable the grid view" : "바둑판식 보기 활성화",
    "Enable folder tree" : "폴더 트리 활성화",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "클립보드로 복사",
    "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하세요.",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2단계 인증을 활성화했다면, 이곳을 클릭해 새로운 앱 암호를 만들어 사용해야 합니다.",
    "Keyboard shortcuts" : "키보드 단축키",
    "Speed up your Files experience with these quick shortcuts." : "이 빠른 단축키를 사용하여 파일 사용 속도를 높이세요.",
    "Open the actions menu for a file" : "파일 작업 메뉴 열기",
    "Rename a file" : "파일 이름 바꾸기",
    "Delete a file" : "파일 삭제",
    "Favorite or remove a file from favorites" : "즐겨찾기에 파일 등록 또는 제거",
    "Manage tags for a file" : "파일 태그 관리",
    "Deselect all files" : "모든 파일 선택 해제",
    "Select or deselect a file" : "파일 선택 또는 선택 해제",
    "Select a range of files" : "파일 범위 선택",
    "Navigate to the parent folder" : "상위 폴더로 이동",
    "Navigate to the file above" : "위 파일로 이동",
    "Navigate to the file below" : "아래 파일로 이동",
    "Navigate to the file on the left (in grid mode)" : "왼쪽 파일로 이동 (그리드 모드에서)",
    "Navigate to the file on the right (in grid mode)" : "오른쪽 파일로 이동 (그리드 모드에서)",
    "Toggle the grid view" : "바둑판식 보기 전환",
    "Open the sidebar for a file" : "파일 사이드바 열기",
    "You" : "당신",
    "Shared multiple times with different people" : "여러 사용자와 공유됨",
    "Error while loading the file data" : "파일 데이터를 불러오는 중 오류 발생",
    "Tags" : "태그",
    "Save as …" : "... 으로 저장하기",
    "Converting files …" : "파일 변환하기 ...",
    "Deletion cancelled" : "삭제가 취소됨",
    "Edit locally" : "로컬에서 편집",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 이동...",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\"을(를) \"{destination}\"(으)로 복사...",
    "Move cancelled" : "이동이 취소됨",
    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"의 이동 또는 복사를 취소했습니다.",
    "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
    "Open details" : "자세한 정보 열기",
    "Photos and images" : "사진과 이미지",
    "New folder creation cancelled" : "새 폴더 생성 취소됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "All folders" : "모든 폴더",
    "Search everywhere …" : "모든 곳에서 검색 ...",
    "Search here …" : "여기서 검색 ..."
},
"nplurals=1; plural=0;");
